<?php

/*
*
* INFOATCLUSTER TECHNOLABS LLP ("COMPANY") CONFIDENTIAL
* Copyright (c) 2016-2017 INFOATCLUSTER TECHNOLABS LLP, All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of INFOATCLUSTER TECHNOLABS LLP. The intellectual and technical concepts contained
* herein are proprietary to INFOATCLUSTER TECHNOLABS LLP and may be covered by Indian and Foreign Patents, patents in process, and are protected by trade secret or copyright law.
* Dissemination of this information or reproduction of this material is strictly forbidden unless prior written permission is obtained
* from COMPANY.  Access to the source code contained herein is hereby forbidden to anyone except current COMPANY employees, managers or contractors who have executed 
* Confidentiality and Non-disclosure agreements explicitly covering such access.
*
* The copyright notice above does not evidence any actual or intended publication or disclosure  of  this source code, which includes  
* information that is confidential and/or proprietary, and is a trade secret, of  COMPANY.   ANY REPRODUCTION, MODIFICATION, DISTRIBUTION, PUBLIC  PERFORMANCE, 
* OR PUBLIC DISPLAY OF OR THROUGH USE  OF THIS  SOURCE CODE  WITHOUT  THE EXPRESS WRITTEN CONSENT OF COMPANY IS STRICTLY PROHIBITED, AND IN VIOLATION OF APPLICABLE 
* LAWS AND INTERNATIONAL TREATIES.  THE RECEIPT OR POSSESSION OF  THIS SOURCE CODE AND/OR RELATED INFORMATION DOES NOT CONVEY OR IMPLY ANY RIGHTS  
* TO REPRODUCE, DISCLOSE OR DISTRIBUTE ITS CONTENTS, OR TO MANUFACTURE, USE, OR SELL ANYTHING THAT IT  MAY DESCRIBE, IN WHOLE OR IN PART.                
*
*
* @author Mohammed Shayas M K
* 
*/

namespace App\Managers\User;
use App\Managers\User\UserModel;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\DB;
use App\Http\Helper\Helper;
use App\Managers\Profile\ProfileManager;
use App\Managers\Paypal\PaypalManager;
use Carbon\Carbon;


class UserManager extends UserModel
{
    public function __construct()
    {
        $this->profileManager = new ProfileManager();
        
         $this->helper = new Helper();
    }

    public function register($data)
    {
        $this->paypalManager = new PaypalManager();
        $data['password'] = Hash::make($data['password'] . 'abcdef45674');
        unset($data['confirm_password']);
        
        $data['ip'] = $_SERVER['REMOTE_ADDR'];

        DB::beginTransaction();
        try 
        {
            $profile = $this->profileManager->first();
            if(!$profile)
            {
                DB::rollback();
                return 0;
            }

            $userID = $this->insert($data);
            if(!$userID)
            {
                DB::rollback();
                return 0;
            }

            if($profile['vote_on_registration'] == 1)
            {
                for($i = 1; $i <= $profile['no_of_votes_on_registration']; $i++)
                {
                    $data1['UUID'] = $this->helper->addUuid();
                    $data1['payment_date'] = date("Y-m-d H:i:s");
                    $data1['expiry_date'] = date('Y-m-d', strtotime('+' . $profile['expiry_by'] . ' days'));
                    $data1['no_of_votes'] = 1;
                    $data1['type'] = 'Registration Bonus';
                    $data1['user_id'] = $data['UUID'];
                    $data1['created_at'] = $data['updated_at'] = $data['created_at'];
                    $res = $this->paypalManager->insert($data1);
                    if(!$res)
                    {
                        DB::rollback();
                        return 0;
                    }
                }
            }

            DB::commit();
            return 1;
        }
        catch(ValidationException $e)
        {
            DB::rollback();
            return 0;
        }
    }
    
    public function confirmAccount($confirmationCode, $UUID)
    {
        if($confirmationCode == '1')
        {
            return 0;
        }
        $user = $this->where('confirmation_code', $confirmationCode)->where('UUID', $UUID)->first();
        if(!$user)
        {
            return 0;
            exit;
        }
        $data['confirmation_code'] = $data['active'] = 1;
        return $this->where('id', $user['id'])->update($data);
    }
    
    public function add($data)
    {
        $data['password'] = Hash::make($data['password'] . 'abcdef45674');
        $data['active'] = 1;
        $data['confirmation_code'] = 1;
        $data['ip'] = $_SERVER['REMOTE_ADDR'];
        return $this->insert($data);
    }
    
    public function updateData($data, $UUID)
    {
        return $this->where('UUID', $UUID)->update($data);
    }
    
    public function becomeMember($UUID)
    {
        return $this->where('UUID', $UUID)->update(array('member' => 1));
    }
    
    public function deleteData($UUID)
    {
        return $this->where('UUID', $UUID)->delete();
    }
    
    public function getTotalUsersCount()
    {
        return $this->select(DB::raw('COUNT(*) AS total'))->whereNull('deleted_at')->first();
    }
    
    public function getTotalActiveVotesUsersCount()
    {
        return $this->select(DB::raw('COUNT(*) AS total'))->join('paypal', 'users.UUID', '=', 'paypal.user_id')->where('users.active', 1)->whereDate('expiry_date', '>=', Carbon::now())->whereNull('users.deleted_at')->groupBy('paypal.user_id')->get();
    }
    
    public function resetPasswordCode($data, $email)
    {
        return $this->where('email', $email)->update($data);
    }
    
}